@@ -1,11 +1,8 @@
 from django.contrib import admin
 from simple_import.models import ImportLog, ColumnMatch
 
-class ColumnMatchInline(admin.TabularInline):
-    model = ColumnMatch
-    extra = 0
-
 class ImportLogAdmin(admin.ModelAdmin):
     list_display = ('name', 'user', 'date',)
-    #inlines = [ColumnMatchInline]
+    def has_add_permission(self, request):
+        return False
 admin.site.register(ImportLog, ImportLogAdmin)
